@@ -1,19 +1,16 @@
 use std::error::Error;
 
 #[cfg(feature = "ko-dic")]
-#[tokio::main]
-async fn main() -> Result<(), Box<dyn Error>> {
+fn main() -> Result<(), Box<dyn Error>> {
     use std::env;
-    use std::fs::{create_dir, rename};
-    use std::io::Cursor;
+    use std::fs::{create_dir, rename, File};
+    use std::io::{self, Cursor, Read, Write};
     use std::path::Path;
 
     use encoding::all::UTF_8;
     use encoding::{EncoderTrap, Encoding};
     use flate2::read::GzDecoder;
     use tar::Archive;
-    use tokio::fs::File;
-    use tokio::io::{AsyncReadExt, AsyncWriteExt};
 
     use lindera_core::dictionary_builder::DictionaryBuilder;
     use lindera_ko_dic_builder::ko_dic_builder::KodicBuilder;
@@ -37,24 +34,22 @@ async fn main() -> Result<(), Box<dyn Error>> {
         // Use dummy data in docs.rs.
         create_dir(&input_dir)?;
 
-        let mut dummy_char_def = File::create(input_dir.join("char.def")).await?;
-        dummy_char_def.write_all(b"DEFAULT 0 1 0\n").await?;
+        let mut dummy_char_def = File::create(input_dir.join("char.def"))?;
+        dummy_char_def.write_all(b"DEFAULT 0 1 0\n")?;
 
-        let mut dummy_dict_csv = File::create(input_dir.join("dummy_dict.csv")).await?;
-        dummy_dict_csv
-            .write_all(
-                &UTF_8
-                    .encode(
-                        "테스트,1785,3543,4721,NNG,행위,F,테스트,*,*,*,*\n",
-                        EncoderTrap::Ignore,
-                    )
-                    .unwrap(),
-            )
-            .await?;
+        let mut dummy_dict_csv = File::create(input_dir.join("dummy_dict.csv"))?;
+        dummy_dict_csv.write_all(
+            &UTF_8
+                .encode(
+                    "테스트,1785,3543,4721,NNG,행위,F,테스트,*,*,*,*\n",
+                    EncoderTrap::Ignore,
+                )
+                .unwrap(),
+        )?;
 
-        File::create(input_dir.join("unk.def")).await?;
-        let mut dummy_matrix_def = File::create(input_dir.join("matrix.def")).await?;
-        dummy_matrix_def.write_all(b"0 1 0\n").await?;
+        File::create(input_dir.join("unk.def"))?;
+        let mut dummy_matrix_def = File::create(input_dir.join("matrix.def"))?;
+        dummy_matrix_def.write_all(b"0 1 0\n")?;
     } else {
         // Source file path for build package
         let source_path_for_build = Path::new(&build_dir).join(&file_name);
@@ -67,20 +62,19 @@ async fn main() -> Result<(), Box<dyn Error>> {
             // Download a tarball
             let download_url =
                 "https://bitbucket.org/eunjeon/mecab-ko-dic/downloads/mecab-ko-dic-2.1.1-20180720.tar.gz";
-            let mut resp = reqwest::get(download_url).await?;
+            let resp = ureq::get(download_url).call()?;
+            let mut dest = File::create(&tmp_path)?;
+
+            io::copy(&mut resp.into_reader(), &mut dest)?;
+            dest.flush()?;
 
-            // Save a ttarball
-            let mut dest = File::create(&tmp_path).await?;
-            while let Some(chunk) = resp.chunk().await? {
-                dest.write_all(&chunk).await?;
-            }
             rename(tmp_path, &source_path_for_build).expect("Failed to rename temporary file");
         }
 
         // Decompress a tarball
-        let mut tar_gz = File::open(&source_path_for_build).await?;
+        let mut tar_gz = File::open(&source_path_for_build)?;
         let mut buffer = Vec::new();
-        tar_gz.read_to_end(&mut buffer).await?;
+        tar_gz.read_to_end(&mut buffer)?;
         let cursor = Cursor::new(buffer);
         let gzdecoder = GzDecoder::new(cursor);
         let mut archive = Archive::new(gzdecoder);
@@ -95,7 +89,6 @@ async fn main() -> Result<(), Box<dyn Error>> {
 }
 
 #[cfg(not(feature = "ko-dic"))]
-#[tokio::main]
-async fn main() -> Result<(), Box<dyn Error>> {
+fn main() -> Result<(), Box<dyn Error>> {
     Ok(())
 }
